function [state_vec, state_dot] = CO_with_bias(imu1, imu2, imu3, imu4, oqus, omega)

%Translating all oqus angles from degrees to radians
oqus(5:7,:) = deg2rad(oqus(5:7,:));

%Translating all positions to coordinate frame coinciding with body
oqus(2:4,:) = -1.*oqus(2:4,:);

%Transforming measured accelerations to mm/s^2
imu1(5:7,:) = imu1(5:7,:).*9.81;
imu2(5:7,:) = imu2(5:7,:).*9.81;
imu3(5:7,:) = imu3(5:7,:).*9.81;
imu4(5:7,:) = imu4(5:7,:).*9.81;

%Translating all accelerations to CO
%State vector x = [p_v, v, g, b_l, w, b_w]' according to Kjerstad

%Measured position of each IMU relative CO defined in Quali
l1 = [-465, -184, -73];
l2 = [-244, 184, -13];
l3 = [740, 130, 82];
l4 = [450, -160, 82];

H1 = Hmatrix(l1);
H2 = Hmatrix(l2);
H3 = Hmatrix(l3); 
H4 = Hmatrix(l4);

S1 = Smtrx(l1);
S2 = Smtrx(l2);
S3 = Smtrx(l3);
S4 = Smtrx(l4);

G = [eye(3), -S1, H1; eye(3), -S2, H2; eye(3), -S3, H3; eye(3), -S4, H4];
G_inv = inv(G);


%Initial states
p0 = Rzyx(oqus(5,20), oqus(6,20), oqus(7,20))'*oqus(2:4,1);
x = [p0; zeros(5,1); -9840; zeros(9,1)];
P = eye(18);

%Selection matrices
B1 = [eye(3), zeros(3,9)];
B2 = [zeros(3,3), eye(3), zeros(3,6)];

H = [eye(3), zeros(3,15); zeros(3,12), eye(3), zeros(3,3)];

%Covariance matrices for Kalman Filter
Q = blkdiag(zeros(3,3),5*eye(3),zeros(3,3),diag([1, 1, 0]),diag([0.08, 0.08, 0.01]),10*eye(3));
R = blkdiag(0.8*eye(3), 10^-6*eye(3));

%Gain matrix
BG_inv = [zeros(3,12); B1; zeros(6,12); B2; zeros(3,12)]*G_inv;

%Acceleration output
state_vec = [];
state_dot = [];
z = [];
y = [];
w = [];

j = 1;          %Counter for oqus measurements
stop = min([length(omega), length(imu1(1,:))]);
for i = 1:stop
    a_m = [imu1(5:7,i); imu2(5:7,i); imu3(5:7,i); imu4(5:7,i)];
    while imu1(1,i) ~= oqus(1,j) %Finding corresponding oqus measurement
        j = j+1;
    end
    
    %System matrix
    A = [-Smtrx(omega(1:3,i)), -eye(3), zeros(3,12);...
        zeros(3,3), -Smtrx(omega(1:3,i)), -eye(3), -eye(3), zeros(3,6);...
        zeros(3,6), -Smtrx(omega(1:3,i)), zeros(3,9);...
        zeros(3,18); ...
        zeros(3,15), -eye(3);...
        zeros(3,18)];

    w(:,i) = (-Smtrx(omega(1:3,i))*x(4:6))';
    z(:,i) = BG_inv*a_m;
    
    %Discretization using ZOH
    [A_disc, B_disc] = c2d(A, BG_inv, 0.05);
    %B_disc(1:3,1:12) = zeros(3,12);
    
    K = P*H'*inv(H*P*H'+R);
    y(:,i) = [Rzyx(oqus(5,j),oqus(6,j),oqus(7,j))'*oqus(2:4,j);omega(1:3,i)];
    x = x+K*(y(:,i) - H*x);
    state_vec(:,i) = x;
    state_dot(:,i) = A*x+BG_inv*a_m;
    P = (eye(18)-K*H)*P*(eye(18)-K*H)'+K*R*K';
    %Predicting next state
    x = A_disc*x + B_disc*a_m;
    P = A_disc*P*A_disc'+Q;
end


end