function [state_vec, acc_est, z] = local_acc_bias(imu_raw, l, oqus, omega)

%Translating all oqus angles from degrees to radians
oqus(5:7,:) = deg2rad(oqus(5:7,:));

%Translating all positions to coordinate system parallel to NED, with
%origin coinciding with CO
oqus(2:4,:) = oqus(2:4,:).*(-1);

%Transforming measured accelerations to mm/s^2
imu_raw(5:7,:) = imu_raw(5:7,:).*9.81;

%Estimating local accelerations for each IMU

%Initial states
p0 = Rzyx(omega(1,20), omega(2,20), omega(3,20))'*oqus(2:4,1);
x = [p0; zeros(5,1); -9810; zeros(3,1)];
P = eye(12);

%Constant system matrices
B = [zeros(3,3); eye(3); zeros(6,3)];
C = [eye(3), zeros(3,9)];

%Covariance matrices for Kalman Filter
Q = 10^-1.5*blkdiag(zeros(3,3),0.03*diag([1, 1, 1]),zeros(3,3),0.05*diag([1, 1, 1]));
R = 0.8*eye(3);

%Acceleration output
acc_est = [];
state_vec = [];
z = [];
y = [];

j = 1;          %Counter for oqus measurements
stop = min([length(omega), length(imu_raw(1,:))]);
for i = 1:stop
    a_m = [imu_raw(5:7,i)];
    while imu_raw(1,i) ~= oqus(1,j) %Finding corresponding oqus measurement
        j = j+1;
    end
    
    %System matrix
    A = [-Smtrx(omega(1:3,i)), -eye(3), zeros(3,6);...
        zeros(3,3), -Smtrx(omega(1:3,i)), -eye(3), -eye(3);...
        zeros(3,6), -Smtrx(omega(1:3,i)), zeros(3,3);...
        zeros(3,12)];
    
    %Discretization using ZOH
    [A_disc , B_disc] = c2d(A, B, 0.05);
    
    K = P*C'*inv(C*P*C'+R);
    y(:,i) = [Rzyx(oqus(5,j),oqus(6,j),oqus(7,j))'*oqus(2:4,j)+l'];
    x = x+K*(y(:,i) - C*x);
    
    state_vec(:,i) = x;
    acc_est(:,i) = A*x+B*a_m;
    P = (eye(12)-K*C)*P*(eye(12)-K*C)'+K*R*K';
    
    %Acceleration in basin frame
    z(:,i) = Rzyx(oqus(5,j),oqus(6,j),oqus(7,j))*x(4:6);
    
    %Predicting next state
    x = A_disc*x + B_disc*a_m;
    P = A_disc*P*A_disc'+Q;
end

state_vec = [imu_raw(1,1:length(state_vec(1,:))); state_vec];
acc_est = [imu_raw(1,1:length(acc_est(1,:))); acc_est];

end