%This script enables the user to specify which experiments to analyze, with
%the possibility of plotting and saving relevant plots. 
clear all

%Define directory to load raw data from
d = uigetdir;

prompt = {'Plot results in CO? (0/1)','Plot results in SO? (0/1)'};
title = 'Plotting options';
defaultans = {'0','0'};
answer = inputdlg(prompt,title,1,defaultans);

%Load raw data workspace
temp = load(strcat(d,'\\imu1_raw.mat'));
imu1_raw = temp.ans;
temp = load(strcat(d,'\\imu2_raw.mat'));
imu2_raw = temp.ans;
temp = load(strcat(d,'\\imu3_raw.mat'));
imu3_raw = temp.ans;
temp = load(strcat(d,'\\imu4_raw.mat'));
imu4_raw = temp.ans;
temp = load(strcat(d,'\\oqus_measured.mat'));
oqus = temp.ans;
load(strcat(d,'\\rotation_matrix'));

%Store raw data for later usage/plots
old1 = imu1_raw;
old2 = imu2_raw;
old3 = imu3_raw;
old4 = imu4_raw;

%Rotating positive directions of accelerations to align with body frame
imu1_raw(2:7,:) = diag([1, 1, 1, -1, -1, -1])*imu1_raw(2:7,:);
imu2_raw(2:7,:) = diag([1, 1, 1, -1, -1, -1])*imu2_raw(2:7,:);
imu3_raw(2:7,:) = diag([1, 1, 1, -1, -1, -1])*imu3_raw(2:7,:);
imu4_raw(2:7,:) = diag([1, 1, 1, -1, -1, -1])*imu4_raw(2:7,:);

%Rotating all accelerations to body-parallel coordinate system
imu1_raw(2:7,:) = Rot.imu1*imu1_raw(2:7,:);
imu2_raw(2:7,:) = Rot.imu2*imu2_raw(2:7,:);
imu3_raw(2:7,:) = Rot.imu3*imu3_raw(2:7,:);
imu4_raw(2:7,:) = Rot.imu4*imu4_raw(2:7,:);

%Transforming angles from xyz-convention to zyx-convention
oqus = xyz2zyx(oqus);

%Lowpass filter accelerations and angular rates
imu1_lp = lp_filter(imu1_raw, 20);
imu2_lp = lp_filter(imu2_raw, 20);
imu3_lp = lp_filter(imu3_raw, 20);
imu4_lp = lp_filter(imu4_raw, 20);

%Lever arm for each IMU from CO in {b}
l1 = [-465, -184, -73];
l2 = [-244, 184, -13];
l3 = [740, 130, 82];
l4 = [450, -160, 82];

%Calculating average angular rate, used as time-varying input in the LTV
%system in Kjerstad and Skjetne(2016)
avg_omega(1,:) = deg2rad((imu1_lp(2,:)+imu2_lp(2,:)+imu3_lp(2,:)+imu4_lp(2,:))./4);
avg_omega(2,:) = deg2rad((imu1_lp(3,:)+imu2_lp(3,:)+imu3_lp(3,:)+imu4_lp(3,:))./4);
avg_omega(3,:) = deg2rad((imu1_lp(4,:)+imu2_lp(4,:)+imu3_lp(4,:)+imu4_lp(4,:))./4);

%Estimate local accelerations in body frame using KF
[state_vec1, acc_est1, z1] = local_acc_bias(imu1_raw, l1, oqus, avg_omega);
[state_vec2, acc_est2, z2] = local_acc_bias(imu2_raw, l2, oqus, avg_omega);
[state_vec3, acc_est3, z3] = local_acc_bias(imu3_raw, l3, oqus, avg_omega);
[state_vec4, acc_est4, z4] = local_acc_bias(imu4_raw, l4, oqus, avg_omega);

%Calculate direction of incoming waves
[heading] = wave_heading(acc_est1, acc_est2, acc_est3, acc_est4);
figure()
plot(heading(1,:),heading(2,:));

%Translate all measured accelerations to CO using the method of Kjerstad
[CO_bias_state_vec, CO_bias_state_dot] = CO_with_bias(imu1_raw, imu2_raw, imu3_raw, imu4_raw, oqus, avg_omega);

%3D plot of local accelerations
%ThreeD_plot(acc_est1, acc_est2, acc_est3, acc_est4,imu1_raw)

%Differentiating Qualisys measurements
[omega, omega_dot, acc_body] = discrete_diff(oqus);


%Plotting CO results
if str2num(answer{1,1}) == 1
    plot_CO(omega_dot, acc_body, imu1_lp, CO_bias_state_dot)
end

%Plotting SO results
if str2num(answer{2,1}) == 1
    plot_SO(acc_est1, acc_est2, acc_est3, acc_est4, omega, omega_dot, acc_body, l1, l2, l3, l4)
end
